(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      6294,        213]
NotebookOptionsPosition[      5491,        184]
NotebookOutlinePosition[      6009,        204]
CellTagsIndexPosition[      5966,        201]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Euler-Methode fuer Differenzialgleichungen erster Ordnung", "Title"],

Cell["\<\
Analysis II,  D-MATV/D-MATL 
FS 2009
Giovanni Felder, ETH\
\>", "Subsubtitle",
 CellChangeTimes->{{3.446918777546875*^9, 3.44691878709375*^9}}],

Cell["\<\
In diesem Notebook wird die Euler-Methode zur Loesung des Anfangswertproblems \
einer Differenzialgleichung erster Ordnung angewendet.
[Shift-Enter in Inputzellen drucken]
Wir betrachten eine Differenzialgleichung von der Form y'=f(x,y). Eingabe der \
Funktion f (versuchen Sie auch mit anderen Funktionen), der Anfangsbedingung \
und des Bereichs wo die Loesung berechnet wird:\
\>", "Text",
 CellChangeTimes->{3.446918948265625*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", " ", 
  RowBox[{"x", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"y", "^", "2"}], "x"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["x", "0"], "=", "0"}], ";", " ", 
  RowBox[{
   SubscriptBox["y", "0"], "=", "0.93"}], " ", 
  RowBox[{"(*", "Anfangsbedingung", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["x", "max"], "=", "8"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Loesung", " ", "wird", " ", "im", " ", 
    RowBox[{"Intervall", " ", "[", 
     RowBox[{
      SubscriptBox["x", "0"], ",", 
      SubscriptBox["x", "max"]}], "]"}], " ", "berechnet"}], 
   "*)"}]}]}], "Input"],

Cell["\<\
Eingabe des Schritts h. Versuchen Sie verschiedene Werte fuer h und \
vergleichen Sie die Genauigkeit der Loesungen. \
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h", "=", "0.1"}], ";"}], " ", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Iteration", " ", "in", " ", "der", " ", "Euler"}], "-", 
    "Methode"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["N", "it"], "=", 
   RowBox[{
    RowBox[{"IntegerPart", "[", 
     RowBox[{
      SubscriptBox["x", "max"], "/", "h"}], "]"}], "+", "1"}]}], ";", 
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   SubscriptBox["y", "0"]}], ";", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"h", "=", "Schritt"}], ",", " ", 
    RowBox[{
     SubscriptBox["N", "it"], "=", 
     RowBox[{"Anzahl", " ", "Iterationen"}]}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"n", "=", "0"}], ",", " ", 
    RowBox[{"n", "<=", 
     SubscriptBox["N", "it"]}], ",", 
    RowBox[{"n", "++"}], ",", 
    RowBox[{
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}], "=", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "+", 
      RowBox[{"h", " ", 
       RowBox[{"f", "[", 
        RowBox[{
         RowBox[{
          SubscriptBox["x", "0"], "+", 
          RowBox[{"n", " ", "h"}]}], ",", 
         RowBox[{"y", "[", "n", "]"}]}], "]"}]}]}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.446919052265625*^9, 3.44691911615625*^9}, 
   3.446958206484375*^9, 3.446958261890625*^9, {3.446958302125*^9, 
   3.446958302359375*^9}, {3.453285932609375*^9, 3.4532859504375*^9}, {
   3.45328598284375*^9, 3.45328599140625*^9}}],

Cell["Graphische Darstellung:.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"values", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "0"], "+", 
        RowBox[{"i", " ", "h"}]}], ",", 
       RowBox[{"N", "[", 
        RowBox[{"y", "[", "i", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       SubscriptBox["N", "it"]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"values", ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"PointSize", "[", "0.01", "]"}]}]}], "]"}]}], "Input"],

Cell["\<\
Vergleich  mit der Loesung mit eineren raffinierteren numerischen Methode \
NDSolve\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Clear", "[", "y", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solution", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"y", "'"}], "[", "x", "]"}], "\[Equal]", 
        RowBox[{"f", "[", 
         RowBox[{
          RowBox[{"y", "[", "x", "]"}], ",", "x"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"y", "[", "0", "]"}], "\[Equal]", 
        SubscriptBox["y", "0"]}]}], "}"}], ",", "y", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["x", "max"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Y", "=", 
   RowBox[{"y", "/.", 
    RowBox[{"solution", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Y", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SubscriptBox["x", "0"], ",", 
     SubscriptBox["x", "max"]}], "}"}]}], "]"}]}], "Input"]
}, Open  ]]
},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (May 21, 2008)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 74, 0, 127, "Title"],
Cell[667, 25, 153, 5, 69, "Subsubtitle"],
Cell[823, 32, 444, 8, 83, "Text"],
Cell[1270, 42, 757, 24, 82, "Input"],
Cell[2030, 68, 141, 3, 29, "Text"],
Cell[2174, 73, 1536, 46, 102, "Input"],
Cell[3713, 121, 40, 0, 29, "Text"],
Cell[3756, 123, 595, 19, 62, "Input"],
Cell[4354, 144, 107, 3, 29, "Text"],
Cell[4464, 149, 1011, 32, 102, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
